@@ -18,7 +18,7 @@ use File::Path ();
 use Cwd ();
 use Config;
 
-our $VERSION = '0.298';
+our $VERSION = '0.299';
 
 use constant WIN32 => $^O eq 'MSWin32';
 
@@ -60,6 +60,7 @@ sub parse_options {
         "dev" => \($self->{dev}),
         "man-pages" => \($self->{man_pages}),
         "home=s" => \($self->{home}),
+        "with-develop" => \($self->{with_develop}),
     or exit 1;
 
     $self->{local_lib} = $self->maybe_abs($self->{local_lib}) unless $self->{global};
@@ -236,11 +237,18 @@ sub cmd_install {
     my $num = $master->installed_distributions;
     warn "$num distribution@{[$num > 1 ? 's' : '']} installed.\n";
     $self->cleanup;
-    if ($master->fail) {
-        warn "See $self->{home}/build.log for details.\n";
-        return 1;
+
+    if ($self->{_return_artifacts}) {
+        my $ok = $master->fail ? 0 : 1;
+        return ($ok, $master->{_artifacts});
     } else {
-        return 0;
+        if ($master->fail) {
+            warn "See $self->{home}/build.log for details.\n";
+            return 1;
+        } else {
+            File::Path::rmtree($_) for values %{$master->{_artifacts}};
+            return 0;
+        }
     }
 }
 
@@ -318,6 +326,7 @@ sub load_cpanfile {
     my $cpanfile = Module::CPANfile->load($file);
     my $prereqs = $cpanfile->prereqs_with;
     my $phases = [qw(build test runtime)];
+    push @$phases, 'develop' if $self->{with_develop};
     my $requirements = $prereqs->merged_requirements($phases, ['requires']);
     my $hash = $requirements->as_string_hash;
 
