@@ -7,7 +7,7 @@ use App::cpm::Job;
 use App::cpm::Logger;
 use Module::Metadata;
 use version;
-our $VERSION = '0.298';
+our $VERSION = '0.299';
 
 sub new {
     my ($class, %option) = @_;
@@ -19,6 +19,7 @@ sub new {
         _fail_resolve => +{},
         _fail_install => +{},
         _is_installed => +{},
+        _artifacts => +{},
     }, $class;
     if ($self->{target_perl}) {
         require Module::CoreList;
@@ -350,6 +351,7 @@ sub _register_install_result {
     my $distribution = $self->distribution($job->distfile);
     $distribution->installed(1);
     $self->{installed_distributions}++;
+    $self->{_artifacts}{$job->distvname} = $job->{directory};
     return 1;
 }
 
